==> qtjambi-sensors-5.15.14-sources.jar: io/qt/sensors/QTapReading.java <==
package io.qt.sensors;

import io.qt.*;


/**
 * <p>Represents one reading from the tap sensor</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qtapreading.html">QTapReading</a></p>
 */
public class QTapReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTapReading.class);
    
    /**
     * <p>Java wrapper for Qt enum <a href="http://doc.qt.io/qt-5/qtapreading.html#TapDirection-enum">QTapReading::TapDirection</a></p>
     */
    @QtUnlistedEnum
    public enum TapDirection implements QtEnumerator {
        Undefined(0),
        X(1),
        Y(2),
        Z(4),
        X_Pos(17),
        Y_Pos(34),
        Z_Pos(68),
        X_Neg(257),
        Y_Neg(514),
        Z_Neg(1028),
        X_Both(273),
        Y_Both(546),
        Z_Both(1092);

        static {
            QtJambi_LibraryUtilities.initialize();
        }

        private TapDirection(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static TapDirection resolve(int value) {
            switch (value) {
            case 0: return Undefined;
            case 1: return X;
            case 2: return Y;
            case 4: return Z;
            case 17: return X_Pos;
            case 34: return Y_Pos;
            case 68: return Z_Pos;
            case 257: return X_Neg;
            case 514: return Y_Neg;
            case 1028: return Z_Neg;
            case 273: return X_Both;
            case 546: return Y_Both;
            case 1092: return Z_Both;
            default: throw new QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTapReading() {
        this((io.qt.core.QObject)null);
    }
    
    public QTapReading(io.qt.core.@Nullable QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTapReading instance, io.qt.core.QObject parent);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #isDoubleTap()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final boolean getDoubleTap() {
        return isDoubleTap();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapreading.html#doubleTap-prop">QTapReading::isDoubleTap()const</a></p>
     */
    @QtPropertyReader(name="doubleTap")
    @QtUninvokable
    public final boolean isDoubleTap(){
        return isDoubleTap_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isDoubleTap_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapreading.html#setDoubleTap">QTapReading::setDoubleTap(bool)</a></p>
     */
    @QtUninvokable
    public final void setDoubleTap(boolean doubleTap){
        setDoubleTap_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), doubleTap);
    }
    
    @QtUninvokable
    private native void setDoubleTap_native_bool(long __this__nativeId, boolean doubleTap);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapreading.html#setTapDirection">QTapReading::setTapDirection(QTapReading::TapDirection)</a></p>
     */
    @QtUninvokable
    public final void setTapDirection(io.qt.sensors.QTapReading.@NonNull TapDirection tapDirection){
        setTapDirection_native_QTapReading_TapDirection(QtJambi_LibraryUtilities.internal.nativeId(this), tapDirection.value());
    }
    
    @QtUninvokable
    private native void setTapDirection_native_QTapReading_TapDirection(long __this__nativeId, int tapDirection);
    
    /**
     * <p>Kotlin property getter. In Java use {@link #tapDirection()} instead.</p>
     */
    @QtPropertyReader(enabled=false)
    @QtUninvokable
    public final io.qt.sensors.QTapReading.@NonNull TapDirection getTapDirection() {
        return tapDirection();
    }
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qtapreading.html#tapDirection-prop">QTapReading::tapDirection()const</a></p>
     */
    @QtPropertyReader(name="tapDirection")
    @QtUninvokable
    public final io.qt.sensors.QTapReading.@NonNull TapDirection tapDirection(){
        return io.qt.sensors.QTapReading.TapDirection.resolve(tapDirection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @QtUninvokable
    private native int tapDirection_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    protected void copyValuesFrom(io.qt.sensors.@Nullable QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QTapReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QTapReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QTapReading instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-sensors-6.2.1-sources.jar: io/qt/sensors/QTapReading.java <==
package io.qt.sensors;


/**
 * <p>Java wrapper for Qt class QTapReading</p>
 */
public class QTapReading extends io.qt.sensors.QSensorReading
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QTapReading.class);
    
    /**
     * <p>Java wrapper for Qt enum QTapReading::TapDirection</p>
     */
    public enum TapDirection implements io.qt.QtEnumerator {
        Undefined(0),
        X(1),
        Y(2),
        Z(4),
        X_Pos(17),
        Y_Pos(34),
        Z_Pos(68),
        X_Neg(257),
        Y_Neg(514),
        Z_Neg(1028),
        X_Both(273),
        Y_Both(546),
        Z_Both(1092);

        private TapDirection(int value) {
            this.value = value;
        }

        /**
         * {@inheritDoc}
         */
        public int value() {
            return value;
        }

        /**
         * Returns the corresponding enum entry for the given value.
         * @param value
         * @return enum entry
         */
        public static TapDirection resolve(int value) {
            switch (value) {
            case 0: return Undefined;
            case 1: return X;
            case 2: return Y;
            case 4: return Z;
            case 17: return X_Pos;
            case 34: return Y_Pos;
            case 68: return Z_Pos;
            case 257: return X_Neg;
            case 514: return Y_Neg;
            case 1028: return Z_Neg;
            case 273: return X_Both;
            case 546: return Y_Both;
            case 1092: return Z_Both;
            default: throw new io.qt.QNoSuchEnumValueException(value);
            }
        }


        private final int value;
    }
    
    
    /**
     * <p>Overloaded constructor for {@link #QTapReading(io.qt.core.QObject)}
     *  with <code>parent = null</code>.</p>
     */
    public QTapReading() {
        this((io.qt.core.QObject)null);
    }
    
    public QTapReading(io.qt.core.QObject parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QTapReading instance, io.qt.core.QObject parent);
    
    @io.qt.QtPropertyReader(name="doubleTap")
    @io.qt.QtUninvokable
    public final boolean isDoubleTap(){
        return isDoubleTap_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean isDoubleTap_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void setDoubleTap(boolean doubleTap){
        setDoubleTap_native_bool(QtJambi_LibraryUtilities.internal.nativeId(this), doubleTap);
    }
    
    @io.qt.QtUninvokable
    private native void setDoubleTap_native_bool(long __this__nativeId, boolean doubleTap);
    
    @io.qt.QtUninvokable
    public final void setTapDirection(io.qt.sensors.QTapReading.TapDirection tapDirection){
        setTapDirection_native_QTapReading_TapDirection(QtJambi_LibraryUtilities.internal.nativeId(this), tapDirection.value());
    }
    
    @io.qt.QtUninvokable
    private native void setTapDirection_native_QTapReading_TapDirection(long __this__nativeId, int tapDirection);
    
    @io.qt.QtPropertyReader(name="tapDirection")
    @io.qt.QtUninvokable
    public final io.qt.sensors.QTapReading.TapDirection tapDirection(){
        return io.qt.sensors.QTapReading.TapDirection.resolve(tapDirection_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int tapDirection_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    protected void copyValuesFrom(io.qt.sensors.QSensorReading other){
        copyValuesFrom_native_QSensorReading_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native void copyValuesFrom_native_QSensorReading_ptr(long __this__nativeId, long other);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QTapReading(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QTapReading(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QTapReading instance, QDeclarativeConstructor constructor);
    
}
